@@ -16,20 +16,11 @@
 /* gee support @(#) previously cgee.c 4.12 98/01/26 */
 #include "ugee.h"
 
-static MATRIX *VC_GEE_diag_as_vec();
-static MATRIX *VC_GEE_matsqrt();
-static MATRIX *VC_GEE_mat1over();
+static MATRIX *VC_GEE_diag_as_vec(MATRIX *);
+static MATRIX *VC_GEE_matsqrt(MATRIX *);
+static MATRIX *VC_GEE_mat1over(MATRIX *);
 
-void Cgee(x, y, id, n, offset, nobs, p,
-	  parmvec, M_parm, S_beta, S_naivvar, S_robvar,
-	  S_phi, S_R, tol, maxsz, S_iter, silent, errorstate, scale_fix,
-	  compatflag)
-double *x, *y, *id, *offset, *n;
-Sint *nobs, *p, *M_parm, *compatflag;
-Sint *silent, *parmvec;
-Sint *S_iter;
-double *S_beta, *S_naivvar, *S_robvar, *S_phi, *S_R, *tol;
-Sint *maxsz, *errorstate, *scale_fix;
+void Cgee(double *x, double *y, double *id, double *n, double *offset, int *nobs, int *p, int *parmvec, int *M_parm, double *S_beta, double *S_naivvar, double *S_robvar, double *S_phi, double *S_R, double *tol, int *maxsz, int *S_iter, int  *silent, int *errorstate, int *scale_fix, int *compatflag)
 {
 /* MAIN DECLS */
 
@@ -39,12 +30,12 @@ Sint *maxsz, *errorstate, *scale_fix;
     /* MATRIX  *xpx, *xpy, *tmp; */
     MATRIX *beta, *betasave;
     MATRIX *alpha;
-    MATRIX *R, *tmpR, *Ri;
+    MATRIX *R =  NULL, *tmpR, *Ri;
     MATRIX *One, *mui; /*, *Opmui; */
     MATRIX *Ai, *ei, *ete;
     MATRIX *S1, *S2, *Di, *this_R, *S5, *S2i;
-    MATRIX *tempmat1, *tempmat2, *Aop, *Dop, *zi, *DRop;
-    MATRIX *robvar, *naivvar, *lag_wts, *tmpeep, *scratch, *wt;
+    MATRIX *tempmat1, *tempmat2, *Aop = NULL, *Dop, *zi, *DRop;
+    MATRIX *robvar, *naivvar, *lag_wts = NULL , *tmpeep, *scratch, *wt;
     double phi, dni, phiLZ;
     int iter, ini, i2, j2, k;
     int alpha_VC_GEE_bandwidth;
@@ -90,7 +81,7 @@ Sint *maxsz, *errorstate, *scale_fix;
 
 #define set_matrix_array(arrname, nel)				\
     if (!(arrname = (MATRIX **)malloc((unsigned)(nel * sizeof(MATRIX *))))) \
-	error("set_matrix_array (mac): out of memory, requesting %d elements",nel);
+	Rf_error("set_matrix_array (mac): out of memory, requesting %d elements",nel);
 
     set_matrix_array(X, nclust)
     set_matrix_array(Y, nclust)
@@ -147,7 +138,7 @@ Sint *maxsz, *errorstate, *scale_fix;
 	    Rprintf("cloglog link, ");
 	    break;
 	default:
-	    error("unknown link");
+	    Rf_error("unknown link");
 	    break;
 	}
 	switch(var_mean_rel)
@@ -165,7 +156,7 @@ Sint *maxsz, *errorstate, *scale_fix;
 	    Rprintf("Gamma var, ");
 	    break;
 	default:
-	    error("Cgee: unknown var_mean_rel. Dies.");
+	    Rf_error("Cgee: unknown var_mean_rel. Dies.");
 	    break;
 	}
 	switch (corstruct)
@@ -192,7 +183,7 @@ Sint *maxsz, *errorstate, *scale_fix;
 	    Rprintf("fixed corstr . ");
 	    break;
 	default:
-	    error("unknown corstr");
+	    Rf_error("unknown corstr");
 	    break;
 	}
 	Rprintf("\n");
@@ -263,7 +254,7 @@ Sint *maxsz, *errorstate, *scale_fix;
 		     || ISNAN(maxfitted))
 		    && var_mean_rel == (int) Binomial)
 		{
-		    error("Cgee: error: logistic model for probability has fitted value very close to 1.\nestimates diverging; iteration terminated.");
+		    Rf_error("Cgee: error: logistic model for probability has fitted value very close to 1.\nestimates diverging; iteration terminated.");
 		}
 		VC_GEE_destroy_matrix(tempmat1);
 		break;
@@ -281,7 +272,7 @@ Sint *maxsz, *errorstate, *scale_fix;
 		     || ISNAN(maxfitted))
 		    && var_mean_rel == (int) Binomial)
 		{
-		    error("Cgee: estimates diverging; iteration terminated");
+		    Rf_error("Cgee: estimates diverging; iteration terminated");
 		}
 		break;
 
@@ -296,12 +287,12 @@ Sint *maxsz, *errorstate, *scale_fix;
 		     || ISNAN(maxfitted))
 		    && var_mean_rel == (int) Binomial)
 		{
-		    error("Cgee: error: cloglog model for probability has fit ted value very close to 1.\nestimates diverging; iteration terminated.");
+		    Rf_error("Cgee: error: cloglog model for probability has fit ted value very close to 1.\nestimates diverging; iteration terminated.");
 		}
 		break;
 
 	    default:
-		error("Cgee: unknown link. Dies.");
+		Rf_error("Cgee: unknown link. Dies.");
 		break;
 	    }
 	    make_permanent(mui);
@@ -323,7 +314,7 @@ Sint *maxsz, *errorstate, *scale_fix;
 		Ai = VC_GEE_form_diag(VC_GEE_px1_times_pxq(mui, mui));
 		break;
 	    default:
-		error("Cgee: unknown var_mean_rel. Dies.");
+		Rf_error("Cgee: unknown var_mean_rel. Dies.");
 		break;
 	    }
 	    VC_GEE_destroy_matrix(mui);
@@ -342,7 +333,7 @@ Sint *maxsz, *errorstate, *scale_fix;
 	    if (corstruct == (int) stat_M_dep || corstruct == (int) AR_M)
 	    {
 		if (dni < (double)alpha_VC_GEE_bandwidth)
-		    error("cgee: M-dependence, M=%d, but clustsize=%d\nfatal error for this model",(int)*M_parm,(int)dni);
+		    Rf_error("cgee: M-dependence, M=%d, but clustsize=%d\nfatal error for this model",(int)*M_parm,(int)dni);
 
 		lag_wts = VC_GEE_create_matrix(1, alpha_VC_GEE_bandwidth, PERMANENT);
 		MEL(lag_wts, 0, 0) = (double)1.;
@@ -382,7 +373,7 @@ Sint *maxsz, *errorstate, *scale_fix;
 	    case fixed:
 		break;
 	    default:
-		error("corstruct not implemented.");
+		Rf_error("corstruct not implemented.");
 		break;
 	    }
 	    VC_GEE_destroy_matrix(ei);
@@ -455,7 +446,7 @@ Sint *maxsz, *errorstate, *scale_fix;
 	case fixed:
 	    break;
 	default:
-	    error("corstruct not implemented.");
+	    Rf_error("corstruct not implemented.");
 	    break;
 	}
 	make_permanent(R);
@@ -530,7 +521,7 @@ Sint *maxsz, *errorstate, *scale_fix;
 		break;
 
 	    default:
-		error("Cgee: unknown link. Dies.");
+		Rf_error("Cgee: unknown link. Dies.");
 		break;
 	    }
 	    make_permanent(mui);
@@ -556,7 +547,7 @@ Sint *maxsz, *errorstate, *scale_fix;
 					   mui, mui));
 		break;
 	    default:
-		error("Cgee: unknown var_mean_rel. Dies.");
+		Rf_error("Cgee: unknown var_mean_rel. Dies.");
 		break;
 	    }
 	    VC_GEE_destroy_matrix(mui);
@@ -620,8 +611,8 @@ Sint *maxsz, *errorstate, *scale_fix;
 
     if (iter >= *maxiter)
     {
-	warning("Maximum number of iterations consumed");
-	warning("Convergence not achieved; results suspect");
+	Rf_warning("Maximum number of iterations consumed");
+	Rf_warning("Convergence not achieved; results suspect");
 	*errorstate = MAXITER_EXCEEDED ;
     }
 
@@ -697,7 +688,7 @@ Sint *maxsz, *errorstate, *scale_fix;
 	    break;
 
 	default:
-	    error("Cgee: unknown link. Dies.");
+	    Rf_error("Cgee: unknown link. Dies.");
 	    break;
 	}
 	make_permanent(mui);
@@ -720,7 +711,7 @@ Sint *maxsz, *errorstate, *scale_fix;
 				       mui, mui));
 	    break;
 	default:
-	    error("Cgee: unknown var_mean_rel. Dies.\n");
+	    Rf_error("Cgee: unknown var_mean_rel. Dies.\n");
 	    break;
 	}
 	VC_GEE_destroy_matrix(mui);
@@ -772,8 +763,8 @@ Sint *maxsz, *errorstate, *scale_fix;
     make_permanent(S2i);
     if (*scale_fix) phi = *S_phi;
     if (*scale_fix && var_mean_rel == Gaussian)
-	warning("Scale parameter fixed at %f with Gaussian variance function",
-		*S_phi);
+	Rf_warning("Scale parameter fixed at %f with Gaussian variance function",
+		   *S_phi);
     naivvar = VC_GEE_scalar_times_matrix(phi, S2i);
     robvar = VC_GEE_matmult(VC_GEE_matmult (S2i, S5), S2i);
 
@@ -807,10 +798,9 @@ Sint *maxsz, *errorstate, *scale_fix;
 
 /* @(#) chanmat.nw 1.3 94/03/09 */
 
-static MATRIX *VC_GEE_create_matrix(nrows, ncols, permanence)
+static MATRIX *VC_GEE_create_matrix(int nrows, int ncols, int permanence)
 /* $Y = |VC_GEE_create_matrix|(r,c,\cdot) :\Rightarrow Y \in M_{r\times c} \wedge
 Y = 0 $ */
-int nrows, ncols, permanence;
 {
     MATRIX *tmp;
     double *head;
@@ -820,8 +810,8 @@ int nrows, ncols, permanence;
 
     if (tmp == NULL)
     {
-	error("VC_GEE_create_matrix: malloc failed %d",
-	      sizeof(struct matrix));
+	Rf_error("VC_GEE_create_matrix: malloc failed %lu",
+	      (unsigned long) sizeof(struct matrix));
     }
 
     tmp->nrows = nrows;
@@ -832,7 +822,7 @@ int nrows, ncols, permanence;
 
     if (tmp->data == NULL)
     {
-	error("VC_GEE_create_matrix: malloc failed, nrows=%d ncols=%d",
+	Rf_error("VC_GEE_create_matrix: malloc failed, nrows=%d ncols=%d",
 	      nrows, ncols);
     }
 
@@ -846,8 +836,7 @@ int nrows, ncols, permanence;
     return tmp;
 }
 
-static void VC_GEE_destroy_matrix(mat)
-MATRIX *mat;
+static void VC_GEE_destroy_matrix(MATRIX *mat)
 {
     if (mat == (MATRIX *) NULL) return;
     mat->nrows = 0;
@@ -860,12 +849,11 @@ MATRIX *mat;
 
 
 
-static MATRIX *VC_GEE_transp(mat)
+static MATRIX *VC_GEE_transp(MATRIX *mat)
 /*
 $Y = VC_GEE_transp(X_{r\times c}) :\Rightarrow Y \in M_{c\times r} \wedge
 y_{ji} = x_{ij}. $
 */
-MATRIX *mat;
 {
     double *telem, *inelem, *tbase;
     int nelem;
@@ -887,16 +875,13 @@ MATRIX *mat;
 
 }
 
-static MATRIX *VC_GEE_corner(mat, nr, nc)
+static MATRIX *VC_GEE_corner(MATRIX *mat, int nr, int nc)
 /*
 $ r \leq r^{\prime} \wedge c \leq c^{\prime}
 \wedge X \in M_{r^{\prime} \times c^{\prime}}
 \wedge Y = $|VC_GEE_corner(X,r,c)|$ :\Rightarrow $ */
 /* $ Y \in M_{r \times c} \wedge y_{ij} = x_{ij},
 \thinspace 1 \leq i \leq r, \thinspace 1 \leq j \leq c $ */
-
-MATRIX *mat;
-int nr, nc;
 {
     MATRIX *tmp;
     double *load;
@@ -905,7 +890,7 @@ int nr, nc;
     sc = mat->ncols;
     if ((nr > sr) || (nc > sc))
     {
-	error("VC_GEE_corner: request not a submatrix.\nfatal error");
+	Rf_error("VC_GEE_corner: request not a submatrix.\nfatal error");
     }
     tmp = VC_GEE_create_matrix(nr, nc, EPHEMERAL);
     load = tmp->data;
@@ -921,11 +906,8 @@ int nr, nc;
 }
 
 
-static MATRIX *VC_GEE_extract_rows(Source,VC_GEE_start,end)
+static MATRIX *VC_GEE_extract_rows(MATRIX *Source, int VC_GEE_start, int end)
 	/* purely zero-based */
-
-MATRIX *Source;
-int VC_GEE_start, end;
 {
     MATRIX *temp;
     int rows_to_get, i, j;
@@ -946,9 +928,7 @@ int VC_GEE_start, end;
     return temp;
 }
 
-static MATRIX *VC_GEE_extract_cols(x, VC_GEE_start, end)
-MATRIX *x;
-int VC_GEE_start, end;
+static MATRIX *VC_GEE_extract_cols(MATRIX *x, int VC_GEE_start, int end)
 {
     MATRIX *tmp;
     tmp = VC_GEE_transp(x);
@@ -958,8 +938,7 @@ int VC_GEE_start, end;
     return tmp;
 }
 
-static MATRIX *VC_GEE_matcopy(inmat)
-MATRIX *inmat;
+static MATRIX *VC_GEE_matcopy(MATRIX *inmat)
 {
     int i, j;
     MATRIX *outmat;
@@ -976,13 +955,12 @@ MATRIX *inmat;
     return outmat;
 }
 
-static int VC_GEE_split(matptr, discptr, matarrptr)
-MATRIX *matptr, *discptr, *matarrptr[];
+static int VC_GEE_split(MATRIX *matptr, MATRIX *discptr, MATRIX *matarrptr[])
 {   /* discriminator VC_GEE_vector assumed to be integer-valued dbls */
     int i, iVC_GEE_start, k, VC_GEE_start, end;
     if (discptr->ncols != 1)
     {
-	error("VC_GEE_split: discriminator must be column vec.\nVC_GEE_split: ncols = %d", discptr->ncols);
+	Rf_error("VC_GEE_split: discriminator must be column vec.\nVC_GEE_split: ncols = %d", discptr->ncols);
     }
 
     k = 0;
@@ -999,7 +977,7 @@ MATRIX *matptr, *discptr, *matarrptr[];
 	    k++;
 	    VC_GEE_start = end+1;
 	    if (i < discptr->nrows) /* don't need iVC_GEE_start at end of loop */
-		iVC_GEE_start = MEL(discptr, i, 0);
+		iVC_GEE_start = (int)MEL(discptr, i, 0);
 	}
 	if (VC_GEE_start < discptr->nrows) end++ ;
     }
@@ -1008,9 +986,7 @@ MATRIX *matptr, *discptr, *matarrptr[];
 }
 
 
-static void VC_GEE_plug(VC_GEE_plugm, socket, row, col)
-int row, col;
-MATRIX *VC_GEE_plugm, *socket;  /* not a unix socket */
+static void VC_GEE_plug(MATRIX *VC_GEE_plugm, MATRIX *socket, int row, int col)
 {
     int pcol, prow;
     double *sockload, *VC_GEE_plughead, *sockrow_VC_GEE_start;
@@ -1021,7 +997,7 @@ MATRIX *VC_GEE_plugm, *socket;  /* not a unix socket */
 
     if (pcol+col > socket->ncols || prow+row > socket->nrows)
     {
-	error("M+-: VC_GEE_plug: socket too small");
+	Rf_error("M+-: VC_GEE_plug: socket too small");
     }
 
     sockload = socket->data + col + row*(socket->ncols);
@@ -1040,8 +1016,7 @@ MATRIX *VC_GEE_plugm, *socket;  /* not a unix socket */
     free_if_ephemeral(VC_GEE_plugm);
 }
 
-static MATRIX *VC_GEE_form_diag(vec)
-MATRIX *vec;
+static MATRIX *VC_GEE_form_diag(MATRIX *vec)
 {
     MATRIX *tmp;
     int i, ord;
@@ -1054,9 +1029,7 @@ MATRIX *vec;
     return tmp;
 }
 
-static MATRIX *VC_GEE_band(in, wid)
-MATRIX *in;
-int wid;
+static MATRIX *VC_GEE_band(MATRIX *in, int wid)
 {
     MATRIX *tmp;
     int i, j;
@@ -1076,8 +1049,7 @@ int wid;
     return tmp;
 }
 
-static MATRIX *VC_GEE_toeplitz(in)
-MATRIX *in;
+static MATRIX *VC_GEE_toeplitz(MATRIX *in)
 {
     MATRIX *toep, *tin, *tmp;
     int n, p, inrows, incols, i, j;
@@ -1087,7 +1059,7 @@ MATRIX *in;
 
     if ((inrows > incols) ? inrows % incols : incols % inrows)
     {
-	error("M+-:VC_GEE_toeplitz: argument invalid");
+	Rf_error("M+-:VC_GEE_toeplitz: argument invalid");
     }
 
     if (inrows > incols)
@@ -1140,8 +1112,7 @@ MATRIX *in;
 
 #define get_nelem(x) (((x)->nrows) * ((x)->ncols))
 
-static double VC_GEE_elsum(x)
-MATRIX *x;
+static double VC_GEE_elsum(MATRIX *x)
 {
     double t=0.;
     double *loc;
@@ -1155,8 +1126,7 @@ MATRIX *x;
     return t;
 }
 
-static MATRIX *VC_GEE_matabs(x)
-MATRIX *x;
+static MATRIX *VC_GEE_matabs(MATRIX *x)
 {
     double *load, *look;
     MATRIX *tmp;
@@ -1172,8 +1142,7 @@ MATRIX *x;
     return tmp ;
 }
 
-static double VC_GEE_matmax(x)
-MATRIX *x;
+static double VC_GEE_matmax(MATRIX *x)
 {
     double t;
     double *loc;
@@ -1192,8 +1161,7 @@ MATRIX *x;
 }
 
 
-static MATRIX *VC_GEE_matexp(x)
-MATRIX *x;
+static MATRIX *VC_GEE_matexp(MATRIX *x)
 {
     double *load, *look;
     MATRIX *tmp;
@@ -1211,15 +1179,14 @@ MATRIX *x;
 
 
 
-static MATRIX *VC_GEE_matadd(mat1, mat2)
-MATRIX *mat1, *mat2;
+static MATRIX *VC_GEE_matadd(MATRIX *mat1, MATRIX *mat2)
 {
     MATRIX *result;
     double *mat1base, *mat2base, *resbase;
     int i, j;
     if ((mat1->ncols != mat2->ncols) || (mat1->nrows != mat2->nrows))
     {
-	error("VC_GEE_matadd: args (%dx%d) + (%dx%d) don't conform.\nfatal error",
+	Rf_error("VC_GEE_matadd: args (%dx%d) + (%dx%d) don't conform.\nfatal error",
 	      mat1->nrows, mat1->ncols, mat2->nrows, mat2->ncols);
     }
     result = VC_GEE_create_matrix(mat1->nrows, mat1->ncols, EPHEMERAL);
@@ -1240,15 +1207,14 @@ MATRIX *mat1, *mat2;
     return result;
 }
 
-static MATRIX *VC_GEE_matsub(mat1, mat2)
-MATRIX *mat1, *mat2;
+static MATRIX *VC_GEE_matsub(MATRIX *mat1, MATRIX *mat2)
 {
     MATRIX *result;
     double *mat1base, *mat2base, *resbase;
     int i, j;
     if ((mat1->ncols != mat2->ncols) || (mat1->nrows != mat2->nrows))
     {
-	error("VC_GEE_matsub: args (%dx%d) + (%dx%d) don't conform.\n",
+	Rf_error("VC_GEE_matsub: args (%dx%d) + (%dx%d) don't conform.\n",
 	      mat1->nrows, mat1->ncols, mat2->nrows, mat2->ncols);
     }
     result = VC_GEE_create_matrix(mat1->nrows, mat1->ncols, EPHEMERAL);
@@ -1269,8 +1235,7 @@ MATRIX *mat1, *mat2;
     return result;
 }
 
-static MATRIX *VC_GEE_matmult(mat1, mat2)
-MATRIX *mat1, *mat2;
+static MATRIX *VC_GEE_matmult(MATRIX *mat1, MATRIX *mat2)
 {
     double *mat1base, *mat1loc, *mat2base, *mat2loc, *resbase;
     MATRIX *result;
@@ -1278,7 +1243,7 @@ MATRIX *mat1, *mat2;
 
     if (mat1->ncols != mat2->nrows)
     {
-	error("VC_GEE_matmult: args (%dx%d) * (%dx%d) don't conform.\n",
+	Rf_error("VC_GEE_matmult: args (%dx%d) * (%dx%d) don't conform.\n",
 	      mat1->nrows, mat1->ncols, mat2->nrows, mat2->ncols);
     }
 
@@ -1312,9 +1277,8 @@ MATRIX *mat1, *mat2;
 
 
 
-static MATRIX *VC_GEE_px1_times_pxq(px1, pxq) /* mult elements of a colvec */
+static MATRIX *VC_GEE_px1_times_pxq(MATRIX *px1, MATRIX *pxq) /* mult elements of a colvec */
 				/* across corresp row of mat */
-MATRIX *px1, *pxq;
 {
     MATRIX *tmp;
     double *load, colel;
@@ -1322,11 +1286,11 @@ MATRIX *px1, *pxq;
 
     if (px1->ncols != 1)
     {
-	error("M+-: VC_GEE_px1_times_pxq: arg1 not a col-vec");
+	Rf_error("M+-: VC_GEE_px1_times_pxq: arg1 not a col-vec");
     }
     if (px1->nrows != pxq->nrows)
     {
-	error("M+-: VC_GEE_px1_times_pxq: args not conforming");
+	Rf_error("M+-: VC_GEE_px1_times_pxq: args not conforming");
     }
     tmp = VC_GEE_matcopy(pxq);
     load = tmp->data;
@@ -1344,20 +1308,19 @@ MATRIX *px1, *pxq;
     return tmp;
 }
 
-static MATRIX *VC_GEE_pxq_divby_px1(pxq, px1) /* divide elements of a colvec */
+static MATRIX *VC_GEE_pxq_divby_px1(MATRIX *pxq, MATRIX *px1) /* divide elements of a colvec */
 				/* into corresp row of mat */
-MATRIX *px1, *pxq;
 {
     MATRIX *tmp;
     double *load, colel;
     int i, j;
     if (px1->ncols != 1)
     {
-	error("M+-: VC_GEE_pxq_divby_px1: arg2 not a col-vec");
+	Rf_error("M+-: VC_GEE_pxq_divby_px1: arg2 not a col-vec");
     }
     if (px1->nrows != pxq->nrows)
     {
-	error("M+-: VC_GEE_pxq_divby_px1: args not conforming");
+	Rf_error("M+-: VC_GEE_pxq_divby_px1: args not conforming");
     }
 
     tmp = VC_GEE_matcopy(pxq);
@@ -1376,9 +1339,7 @@ MATRIX *px1, *pxq;
     return tmp;
 }
 
-static MATRIX *VC_GEE_scalar_times_matrix(a, X)
-double a;
-MATRIX *X;
+static MATRIX *VC_GEE_scalar_times_matrix(double a, MATRIX *X)
 {
     MATRIX *tmp;
     double *tbase;
@@ -1398,8 +1359,7 @@ MATRIX *X;
 
 
 
-static void VC_GEE_matdump(mat)
-MATRIX *mat;
+static void VC_GEE_matdump(MATRIX *mat)
 {
     double *curel;
     int outtok = 0;
@@ -1415,8 +1375,7 @@ MATRIX *mat;
 /* DOES NOT CLEAN */
 }
 
-static MATRIX *VC_GEE_luinv(X)
-MATRIX *X;
+static MATRIX *VC_GEE_luinv(MATRIX *X)
 {
     MATRIX *Y;
     double det[2], *work;
@@ -1455,9 +1414,7 @@ MATRIX *X;
     return Y;
 }
 
-static MATRIX *VC_GEE_covlag(inmat, lag, demean)
-MATRIX *inmat;
-int lag, demean;
+static MATRIX *VC_GEE_covlag(MATRIX *inmat, int lag, int demean)
 {
     MATRIX *xrows[MAX_COVLAG], *res, *temp;
     int n, i, j, nv, q;
@@ -1467,7 +1424,7 @@ int lag, demean;
     nrec = (double)1./(double)n;
     if (n > MAX_COVLAG)
     {
-	error("VC_GEE_covlag: arg has > MAX_COVLAG rows");
+	Rf_error("VC_GEE_covlag: arg has > MAX_COVLAG rows");
     }
 
     nv = inmat->ncols;
@@ -1502,8 +1459,7 @@ int lag, demean;
 
 
 
-static MATRIX *VC_GEE_ident(ord)
-int ord;
+static MATRIX *VC_GEE_ident(int ord)
 {
     MATRIX *I;
     int i;
@@ -1514,8 +1470,7 @@ int ord;
     return I;
 }
 
-static MATRIX *VC_GEE_col_1s(k)
-int k;
+static MATRIX *VC_GEE_col_1s(int k)
 {
     MATRIX *tmp;
     int i;
@@ -1528,8 +1483,7 @@ int k;
 }
 
 
-static int VC_GEE_nchanges(X)
-MATRIX *X;
+static int VC_GEE_nchanges(MATRIX *X)
 {
 /* returns integer telling how often the value of X */
 /* changes from row to row.  X must be column VC_GEE_vector */
@@ -1538,28 +1492,27 @@ MATRIX *X;
 
     if (X->ncols != 1)
     {
-	error("VC_GEE_nchanges:  must be column VC_GEE_vector; ncols = %d",
+	Rf_error("VC_GEE_nchanges:  must be column VC_GEE_vector; ncols = %d",
 	      X->ncols);
     }
 
-    iVC_GEE_start = MEL(X, 0, 0);
+    iVC_GEE_start = (int)MEL(X, 0, 0);
 
     for (i = 1 ; i < X->nrows ; i++)
     {
 	if (MEL (X, i, 0) != iVC_GEE_start)
 	{
 	    tmp++;
-	    iVC_GEE_start = MEL (X, i, 0);
+	    iVC_GEE_start = (int)MEL (X, i, 0);
 	}
     }
     return tmp;
 }
 
-static  MATRIX *VC_GEE_matanticlog(x)
-MATRIX *x;
+static  MATRIX *VC_GEE_matanticlog(MATRIX *x)
 {
     double *load, *look;
-    double exp();
+//    double exp();
     MATRIX *tmp;
     int nelem, i;
 
@@ -1578,15 +1531,14 @@ MATRIX *x;
 /* gee support @(#) VC_GEE_diag_as_vec.c 3.3 94/03/09 */
 
 
-static MATRIX *VC_GEE_diag_as_vec(inmat)
-MATRIX *inmat;
+static MATRIX *VC_GEE_diag_as_vec(MATRIX * inmat)
 {
     int i;
     MATRIX *outmat;
 
     if(inmat->ncols!=inmat->nrows)
     {
-	error("M+-: VC_GEE_diag_as_vec: arg is not a square matrix");
+	Rf_error("M+-: VC_GEE_diag_as_vec: arg is not a square matrix");
     }
 
     outmat= VC_GEE_create_matrix(inmat->nrows,1,EPHEMERAL);
@@ -1599,8 +1551,7 @@ MATRIX *inmat;
 
 
 
-static MATRIX *VC_GEE_matsqrt(x)
-MATRIX *x;
+static MATRIX *VC_GEE_matsqrt(MATRIX *x)
 {
     int i,j;
     MATRIX *tmp;
@@ -1616,8 +1567,7 @@ MATRIX *x;
     return tmp;
 }
 
-static MATRIX *VC_GEE_mat1over(x)
-MATRIX *x;
+static MATRIX *VC_GEE_mat1over(MATRIX *x)
 {
     int i,j;
     MATRIX *tmp;
@@ -1653,11 +1603,10 @@ MATRIX *x;
 
 /* following added by pj catalano to support probit link option in cgee.c */
 
-static MATRIX *VC_GEE_matnpdf(x)
-MATRIX *x;
+static MATRIX *VC_GEE_matnpdf(MATRIX *x)
 {
     double *load, *look;
-    double VC_GEE_npdf();
+    double VC_GEE_npdf(void);
     MATRIX *tmp;
     int nelem, i;
 
@@ -1671,11 +1620,10 @@ MATRIX *x;
     return tmp ;
 }
 
-static MATRIX *VC_GEE_matncdf(x)
-MATRIX *x;
+static MATRIX *VC_GEE_matncdf(MATRIX *x)
 {
     double *load, *look;
-    double VC_GEE_ncdf();
+    double VC_GEE_ncdf(void);
     MATRIX *tmp;
     int nelem, i;
 
